@@ -416,14 +416,18 @@ class InheritDeprecated(LineCheck):
 
 	# deprecated eclass : new eclass (False if no new eclass)
 	deprecated_eclasses = {
+		"autotools-multilib": "multilib-minimal",
+		"autotools-utils": False,
 		"base": False,
 		"bash-completion": "bash-completion-r1",
 		"boost-utils": False,
 		"clutter": "gnome2",
 		"confutils": False,
 		"distutils": "distutils-r1",
+		"fdo-mime": "xdg-utils",
 		"games": False,
 		"gems": "ruby-fakegem",
+		"git-2": "git-r3",
 		"gpe": False,
 		"gst-plugins-bad": "gstreamer",
 		"gst-plugins-base": "gstreamer",
@@ -434,6 +438,7 @@ class InheritDeprecated(LineCheck):
 		"python": "python-r1 / python-single-r1 / python-any-r1",
 		"ruby": "ruby-ng",
 		"x-modular": "xorg-2",
+		"xfconf": False,
 	}
 
 	_inherit_re = re.compile(r'^\s*inherit\s(.*)$')
@@ -687,6 +692,32 @@ class EMakeParallelDisabledViaMAKEOPTS(LineCheck):
 	error = errors.EMAKE_PARALLEL_DISABLED_VIA_MAKEOPTS
 
 
+class UriUseHttps(LineCheck):
+	"""Check that we use https:// for known good sites."""
+	repoman_check_name = 'uri.https'
+	_SITES = (
+		'([-._a-zA-Z0-9]*\.)?apache\.org',
+		'((alioth|packages(\.qa)?|people|www)\.)?debian\.org',
+		# Most FDO sites support https, but not all (like tango).
+		# List the most common ones here for now.
+		'((anongit|bugs|cgit|dri|patchwork|people|specifications|www|xcb|xorg)\.)?freedesktop\.org',
+		'((bugs|dev|wiki|www)\.)?gentoo\.org',
+		'((wiki)\.)?github\.(io|com)',
+		'savannah\.(non)?gnu\.org',
+		'((gcc|www)\.)?gnu\.org',
+		'curl\.haxx\.se',
+		'((bugzilla|git|mirrors|patchwork|planet|www(\.wiki)?)\.)?kernel\.org',
+		'((bugs|wiki|www)\.)?linuxfoundation\.org',
+		'((docs|pypi|www)\.)?python\.org',
+		'(sf|sourceforge)\.net',
+		'(www\.)?(enlightenment|sourceware|x)\.org',
+	)
+	# Try to anchor the end of the URL so we don't get false positives
+	# with http://github.com.foo.bar.com/.  Unlikely, but possible.
+	re = re.compile(r'.*\bhttp://(%s)(\s|["\'/]|$)' % r'|'.join(_SITES))
+	error = errors.URI_HTTPS
+
+
 class NoAsNeeded(LineCheck):
 	"""Check for calls to the no-as-needed function."""
 	repoman_check_name = 'upstream.workaround'
@@ -885,6 +916,19 @@ class PortageInternalVariableAssignment(LineCheck):
 			e += ' on line: %d'
 		return e
 
+
+class EbuildNonRelativeDosym(LineCheck):
+	"""Check ebuild for dosym using absolute paths instead of relative."""
+	repoman_check_name = 'ebuild.absdosym'
+	regex = re.compile(
+		r'^\s*dosym\s+["\']?(/(bin|etc|lib|opt|sbin|srv|usr|var)\S*)')
+
+	def check(self, num, line):
+		match = self.regex.match(line)
+		if match:
+			return "dosym '%s'... could use relative path" % (match.group(1), ) + " on line: %d"
+
+
 _base_check_classes = (InheritEclass, LineCheck, PhaseCheck)
 _constant_checks = None
 
